==> 0.3.24+6.tar.gz: lib/widgets/story/story_wrapper.dart <==
import 'package:feed_plugin/models/story/storyModel.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:feed_plugin/widgets/story/story.dart';
import 'package:feed_plugin/widgets/story/story_button.dart';
import 'package:flutter/material.dart';

class StoryWrapper extends StatefulWidget {
  final loc;
  final FeedRepository? feedRepository;
  final UserModel? currentUser;

  StoryWrapper({
    required this.loc,
    required this.feedRepository,
    required this.currentUser,
  }) : super();

  @override
  _StoryWrapperState createState() => _StoryWrapperState();
}

class _StoryWrapperState extends State<StoryWrapper> {
  List<Widget> storyWidgetList = [];
  @override
  void initState() {
    initAddStoryBtn(widget.currentUser);
    getStories();
    super.initState();
  }

  void initAddStoryBtn(UserModel? currentUser) {
    if (isEnabled()) {
      var storyButton = StoryButtonPage(
        currentUser: currentUser,
        loc: widget.loc,
        onTap: getStories,
      );
      setState(() {
        storyWidgetList.insert(0, storyButton);
      });
    }
  }

  void getStories() async {
    await widget.feedRepository!.getStoriesToday().then((stories) {
      if (stories.isEmpty) {
        setState(() {
          storyWidgetList = [];
        });
        initAddStoryBtn(widget.currentUser);
      }
      stories.forEach((s) {
        var userClip = buildUserClip(s);
        setState(() {
          storyWidgetList.add(userClip);
        });
      });
    });
  }

  bool isEnabled() {
    return widget.currentUser != null && widget.currentUser!.enabled == true;
  }

  bool showStoryRow() {
    return isEnabled() || storyWidgetList.isNotEmpty;
  }

  @override
  Widget build(BuildContext context) {
    return showStoryRow()
        ? Container(
            margin: EdgeInsets.only(bottom: 8),
            height: 113,
            color: Colors.white,
            child: Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Container(
                  margin:
                      EdgeInsets.only(bottom: 5, top: 10, right: 10, left: 10),
                  child: Text(
                    widget.loc.translate("Story"),
                    style: TextStyle(fontSize: 14, fontWeight: FontWeight.w600),
                  ),
                ),
                Expanded(
                  child: ListView(
                    shrinkWrap: true,
                    scrollDirection: Axis.horizontal,
                    children: storyWidgetList,
                  ),
                ),
              ],
            ),
          )
        : Container();
  }

  bool withProfileImg(UserModel? user) {
    return user!.profileImg != null &&
        user.profileImg != "" &&
        user.profileImg != "null";
  }

  Widget buildUserClip(StoryModel story) {
    return GestureDetector(
      onTap: () async {
        await Navigator.push(
          context,
          MaterialPageRoute(
            builder: (context) => StoryPage(
              story: story,
              images: story.attachedUrl!.split("*"),
              currentUser: widget.currentUser,
              text: story.text!.split("K*K"),
              type: story.type!.split("*"),
              loc: widget.loc,
            ),
          ),
        );
        getStories();
      },
      child: Container(
        padding: const EdgeInsets.all(4.0),
        margin: const EdgeInsets.all(4.0),
        height: 60,
        width: 60,
        decoration: new BoxDecoration(
          shape: BoxShape.circle,
          border: new Border.all(
            color: Colors.grey,
            width: 0.6,
          ),
        ),
        child: withProfileImg(story.user)
            ? CircleAvatar(
                backgroundImage: NetworkImage(story.user!.profileImg!),
              )
            : DefaultProfileImg(
                firstName: story.user!.firstName,
                lastName: story.user!.lastName,
                heightProfileImage: 39,
                widthProfileImage: 38,
              ),
      ),
    );
  }
}

==> 0.3.25+2.tar.gz: lib/widgets/story/story_wrapper.dart <==
import 'package:feed_plugin/models/story/storyModel.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:feed_plugin/widgets/story/story.dart';
import 'package:feed_plugin/widgets/story/story_button.dart';
import 'package:flutter/material.dart';

class StoryWrapper extends StatefulWidget {
  final loc;
  final FeedRepository? feedRepository;
  final UserModel currentUser;

  StoryWrapper({
    required this.loc,
    required this.feedRepository,
    required this.currentUser,
  }) : super();

  @override
  _StoryWrapperState createState() => _StoryWrapperState();
}

class _StoryWrapperState extends State<StoryWrapper> {
  List<Widget> storyWidgetList = [];
  @override
  void initState() {
    initAddStoryBtn(widget.currentUser);
    getStories();
    super.initState();
  }

  void initAddStoryBtn(UserModel currentUser) {
    if (isEnabled()) {
      var storyButton = StoryButtonPage(
        currentUser: currentUser,
        loc: widget.loc,
        onTap: getStories,
      );
      setState(() {
        storyWidgetList.insert(0, storyButton);
      });
    }
  }

  void getStories() async {
    await widget.feedRepository!.getStoriesToday().then((stories) {
      if (stories.isEmpty) {
        setState(() {
          storyWidgetList = [];
        });
        initAddStoryBtn(widget.currentUser);
      }
      stories.forEach((s) {
        var userClip = buildUserClip(s);
        setState(() {
          storyWidgetList.add(userClip);
        });
      });
    });
  }

  bool isEnabled() {
    return widget.currentUser.enabled == true;
  }

  bool showStoryRow() {
    return isEnabled() || storyWidgetList.isNotEmpty;
  }

  @override
  Widget build(BuildContext context) {
    return showStoryRow()
        ? Container(
            margin: EdgeInsets.only(bottom: 8),
            height: 113,
            color: Colors.white,
            child: Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Container(
                  margin:
                      EdgeInsets.only(bottom: 5, top: 10, right: 10, left: 10),
                  child: Text(
                    widget.loc.translate("Story"),
                    style: TextStyle(fontSize: 14, fontWeight: FontWeight.w600),
                  ),
                ),
                Expanded(
                  child: ListView(
                    shrinkWrap: true,
                    scrollDirection: Axis.horizontal,
                    children: storyWidgetList,
                  ),
                ),
              ],
            ),
          )
        : Container();
  }

  bool withProfileImg(UserModel user) {
    return user.profileImg != null &&
        user.profileImg != "" &&
        user.profileImg != "null";
  }

  Widget buildUserClip(StoryModel story) {
    return GestureDetector(
      onTap: () async {
        await Navigator.push(
          context,
          MaterialPageRoute(
            builder: (context) => StoryPage(
              story: story,
              images: story.attachedUrl!.split("*"),
              currentUser: widget.currentUser,
              text: story.text!.split("K*K"),
              type: story.type!.split("*"),
              loc: widget.loc,
            ),
          ),
        );
        getStories();
      },
      child: Container(
        padding: const EdgeInsets.all(4.0),
        margin: const EdgeInsets.all(4.0),
        height: 60,
        width: 60,
        decoration: new BoxDecoration(
          shape: BoxShape.circle,
          border: new Border.all(
            color: Colors.grey,
            width: 0.6,
          ),
        ),
        child: withProfileImg(story.user)
            ? CircleAvatar(
                backgroundImage: NetworkImage(story.user.profileImg!),
              )
            : DefaultProfileImg(
                firstName: story.user.firstName,
                lastName: story.user.lastName,
                heightProfileImage: 39,
                widthProfileImage: 38,
              ),
      ),
    );
  }
}
